@@ -1,11 +1,9 @@
-/* vim: set expandtab ts=8 sw=4: */
-
-/*  $Id: panel.c 26672 2008-03-09 19:51:09Z nick $
+/*  $Id$
  *
- *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
+ *  Copyright (c) 2005 Jasper Huijsmans <jasper@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published 
+ *  it under the terms of the GNU General Public License as published
  *  by the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
@@ -32,8 +30,9 @@
 #include <libxfce4panel/xfce-itembar.h>
 #include <libxfce4panel/xfce-panel-item-iface.h>
 
-#include <libxfce4panel/xfce-panel-enum-types.h>
+#include <libxfce4panel/libxfce4panel-enum-types.h>
 #include <libxfce4panel/xfce-panel-convenience.h>
+#include <libxfce4panel/xfce-panel-macros.h>
 
 #include "panel.h"
 #include "panel-app.h"
@@ -68,7 +67,7 @@ static void panel_finalize     (GObject * object);
 
 static void panel_get_property (GObject    *object,
                                 guint       prop_id,
-                                GValue     *value, 
+                                GValue     *value,
                                 GParamSpec *pspec);
 
 static void panel_set_property (GObject      *object,
@@ -78,9 +77,9 @@ static void panel_set_property (GObject      *object,
 
 /* GtkWidget */
 static void panel_size_request  (GtkWidget      *widget,
-			         GtkRequisition *requisition);
+                                 GtkRequisition *requisition);
 
-static gboolean panel_button_pressed (GtkWidget      *widget, 
+static gboolean panel_button_pressed (GtkWidget      *widget,
                                       GdkEventButton *ev);
 
 /* plugin menu */
@@ -90,30 +89,30 @@ static void panel_menu_opened (GtkWidget *item);
 static void _item_start_move (GtkWidget *item, Panel     *panel);
 
 /* DND dest */
-static void _panel_drag_data_received (GtkWidget        *widget, 
-                                       GdkDragContext   *context, 
-                                       gint              x, 
-                                       gint              y, 
-                                       GtkSelectionData *data, 
-                                       guint             info, 
-                                       guint             time, 
+static void _panel_drag_data_received (GtkWidget        *widget,
+                                       GdkDragContext   *context,
+                                       gint              x,
+                                       gint              y,
+                                       GtkSelectionData *data,
+                                       guint             info,
+                                       guint             time_,
                                        Panel            *panel);
 
-static gboolean _panel_drag_drop (GtkWidget      *widget, 
-                                  GdkDragContext *context, 
-                                  gint            x, 
-                                  gint            y, 
-                                  guint           time, 
+static gboolean _panel_drag_drop (GtkWidget      *widget,
+                                  GdkDragContext *context,
+                                  gint            x,
+                                  gint            y,
+                                  guint           time_,
                                   Panel          *panel);
 
 /* DND source */
-static void _panel_drag_begin (GtkWidget      *widget, 
-                               GdkDragContext *drag_context, 
+static void _panel_drag_begin (GtkWidget      *widget,
+                               GdkDragContext *drag_context,
                                Panel          *panel);
 
 /* pass through button press events */
-static gboolean _panel_itembar_button_pressed (GtkWidget      *widget, 
-                                               GdkEventButton *ev, 
+static gboolean _panel_itembar_button_pressed (GtkWidget      *widget,
+                                               GdkEventButton *ev,
                                                Panel          *panel);
 
 /* menu */
@@ -141,7 +140,7 @@ panel_class_init (PanelClass * klass)
 
     widget_class->button_press_event = panel_button_pressed;
     widget_class->size_request       = panel_size_request;
-    
+
     /* properties */
 
     pspec = g_param_spec_int ("size",
@@ -195,7 +194,7 @@ panel_class_init (PanelClass * klass)
     pspec = g_param_spec_int ("fullwidth",
                               "panel_fullwidth",
                               "Use the full screen width",
-                              XFCE_PANEL_NORMAL_WIDTH, 
+                              XFCE_PANEL_NORMAL_WIDTH,
                               XFCE_PANEL_SPAN_MONITORS,
                               DEFAULT_FULL_WIDTH, G_PARAM_READWRITE);
 
@@ -222,8 +221,8 @@ panel_init (Panel * panel)
 {
     PanelPrivate *priv;
 
-    priv = panel->priv    = G_TYPE_INSTANCE_GET_PRIVATE (panel, 
-                                                         PANEL_TYPE_PANEL, 
+    priv = panel->priv    = G_TYPE_INSTANCE_GET_PRIVATE (panel,
+                                                         PANEL_TYPE_PANEL,
                                                          PanelPrivate);
 
     priv->size            = DEFAULT_SIZE;
@@ -236,12 +235,10 @@ panel_init (Panel * panel)
     priv->transparency    = DEFAULT_TRANSPARENCY;
     priv->activetrans     = DEFAULT_ACTIVE_TRANS;
 
-    gtk_window_set_title (GTK_WINDOW (panel), "Xfce Panel");
-
     priv->itembar = xfce_itembar_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (priv->itembar);
     gtk_container_add (GTK_CONTAINER (panel), priv->itembar);
-    
+
     panel_dnd_set_dest_name_and_widget (priv->itembar);
     panel_dnd_set_source_widget (priv->itembar);
 
@@ -249,13 +246,13 @@ panel_init (Panel * panel)
     g_signal_connect (panel, "delete-event", G_CALLBACK (gtk_true), NULL);
 
     /* DND */
-    g_signal_connect (priv->itembar, "drag-data-received", 
+    g_signal_connect (priv->itembar, "drag-data-received",
                       G_CALLBACK (_panel_drag_data_received), panel);
 
-    g_signal_connect (priv->itembar, "drag-drop", 
+    g_signal_connect (priv->itembar, "drag-drop",
                       G_CALLBACK (_panel_drag_drop), panel);
 
-    g_signal_connect (priv->itembar, "drag-begin", 
+    g_signal_connect (priv->itembar, "drag-begin",
                       G_CALLBACK (_panel_drag_begin), panel);
 
     /* mouse click */
@@ -272,14 +269,14 @@ static void
 panel_finalize (GObject * object)
 {
     /* TODO: properly ref and unref private widgets  */
-    
+
     G_OBJECT_CLASS (panel_parent_class)->finalize (object);
 }
 
 static void
-panel_get_property (GObject    *object, 
+panel_get_property (GObject    *object,
                     guint       prop_id,
-                    GValue     *value, 
+                    GValue     *value,
                     GParamSpec *pspec)
 {
     PanelPrivate *priv = PANEL(object)->priv;
@@ -320,9 +317,9 @@ panel_get_property (GObject    *object,
 }
 
 static void
-panel_set_property (GObject      *object, 
+panel_set_property (GObject      *object,
                     guint         prop_id,
-                    const GValue *value, 
+                    const GValue *value,
                     GParamSpec   *pspec)
 {
     Panel *panel = PANEL (object);
@@ -362,8 +359,8 @@ panel_set_property (GObject      *object,
     }
 }
 
-static void 
-panel_size_request  (GtkWidget      *widget, 
+static void
+panel_size_request  (GtkWidget      *widget,
                      GtkRequisition *requisition)
 {
     PanelPrivate *priv = PANEL(widget)->priv;
@@ -382,100 +379,100 @@ panel_size_request  (GtkWidget      *widget,
     }
 }
 
-static gboolean 
-panel_button_pressed (GtkWidget      *widget, 
+static gboolean
+panel_button_pressed (GtkWidget      *widget,
                       GdkEventButton *ev)
 {
     guint modifiers;
 
     modifiers = gtk_accelerator_get_default_mod_mask ();
 
-    if (ev->button == 3 || (ev->button == 1 && 
+    if (ev->button == 3 || (ev->button == 1 &&
         (ev->state & modifiers) == GDK_CONTROL_MASK))
     {
         PanelPrivate *priv;
-    
+
         priv = PANEL (widget)->priv;
 
-        gtk_menu_set_screen (GTK_MENU (priv->menu), 
+        gtk_menu_set_screen (GTK_MENU (priv->menu),
                              gtk_widget_get_screen (widget));
-        
-        gtk_menu_popup (GTK_MENU (priv->menu), NULL, NULL, NULL, NULL, 
+
+        gtk_menu_popup (GTK_MENU (priv->menu), NULL, NULL, NULL, NULL,
                         ev->button, ev->time);
 
         return TRUE;
     }
-    
-    return 
+
+    return
         GTK_WIDGET_CLASS (panel_parent_class)->button_press_event (widget, ev);
 }
 
 /* DND dest */
 static void
-_panel_drag_data_received (GtkWidget        *widget, 
-                           GdkDragContext   *context, 
-                           gint              x, 
-                           gint              y, 
-                           GtkSelectionData *data, 
-                           guint             info, 
-                           guint             time, 
+_panel_drag_data_received (GtkWidget        *widget,
+                           GdkDragContext   *context,
+                           gint              x,
+                           gint              y,
+                           GtkSelectionData *data,
+                           guint             info,
+                           guint             time_,
                            Panel            *panel)
 {
     XfceItembar   *itembar = XFCE_ITEMBAR (widget);
     PanelPrivate  *priv = panel->priv;
     XfcePanelItem *item;
     GtkWidget     *plugin;
-    gint           index;
+    gint           index_;
     gint           oldindex;
     gboolean       expand;
     gboolean       succeed = FALSE;
 
     DBG (" + drag data received: %d", info);
-    
+
     /* get the drop index */
-    index = xfce_itembar_get_drop_index (itembar, x, y);
-    
+    index_ = xfce_itembar_get_drop_index (itembar, x, y);
+
     switch (info)
     {
         case TARGET_PLUGIN_NAME:
             if (data->length > 0)
             {
                 /* insert the new plugin */
-                panel_insert_item (panel, (const gchar *) data->data, index);
-                
+                panel_insert_item (panel, (const gchar *) data->data, index_);
+
                 /* succeeded */
                 succeed = TRUE;
             }
             break;
-           
+
         case TARGET_PLUGIN_WIDGET:
             /* get the plugin from the drag context */
             plugin = gtk_drag_get_source_widget (context);
-            
+
             /* try the drag_widget or leave */
             if (!plugin || !XFCE_IS_PANEL_ITEM (plugin))
                 break;
-            
+
             if (gtk_widget_get_parent (plugin) != widget)
             {
                 /* get the plugin and information */
                 item   = XFCE_PANEL_ITEM (plugin);
                 expand = xfce_panel_item_get_expand (item);
-                
+
                 /* freeze plugin notifications */
                 g_object_freeze_notify (G_OBJECT (widget));
-                
+
                 /* move the plugin from the old panel to the new one */
                 gtk_widget_reparent (GTK_WIDGET (plugin), widget);
-                
+
                 /* update the plugin */
                 xfce_panel_item_set_size (item, priv->size);
                 xfce_panel_item_set_screen_position (item, priv->screen_position);
-                
+
                 /* update the itembar */
-                xfce_itembar_reorder_child (itembar, plugin, index);
+                xfce_itembar_reorder_child (itembar, plugin, index_);
                 xfce_itembar_set_child_expand (itembar, plugin, expand);
-                
+
                 /* thaw update notifications */
                 g_object_thaw_notify (G_OBJECT (widget));
             }
@@ -483,72 +480,72 @@ _panel_drag_data_received (GtkWidget        *widget,
             {
                 /* get the old index */
                 oldindex = xfce_itembar_get_item_index (itembar, plugin);
-                
-                if (index > oldindex)
-                    index--;
-                    
-                if (index != oldindex)
-                    xfce_itembar_reorder_child (itembar, plugin, index);
+
+                if (index_ > oldindex)
+                    index_--;
+
+                if (index_ != oldindex)
+                    xfce_itembar_reorder_child (itembar, plugin, index_);
             }
-            
+
             /* properly handled */
             succeed = TRUE;
-            
+
             break;
-           
+
         default:
             break;
     }
-    
+
     /* finish the drag */
-    gtk_drag_finish (context, succeed, FALSE, time);
+    gtk_drag_finish (context, succeed, FALSE, time_);
 }
 
 static gboolean
-_panel_drag_drop (GtkWidget      *widget, 
-                  GdkDragContext *context, 
-                  gint            x, 
-                  gint            y, 
-                  guint           time, 
+_panel_drag_drop (GtkWidget      *widget,
+                  GdkDragContext *context,
+                  gint            x,
+                  gint            y,
+                  guint           time_,
                   Panel          *panel)
 {
     GdkAtom target = gtk_drag_dest_find_target (widget, context, NULL);
-    
+
     /* we cannot handle the drag data */
     if (G_UNLIKELY (target == GDK_NONE))
         return FALSE;
 
     /* request the drag data */
-    gtk_drag_get_data (widget, context, target, time);
-  
+    gtk_drag_get_data (widget, context, target, time_);
+
     /* we call gtk_drag_finish later */
     return TRUE;
 }
 
 /* DND source */
 static void
-_panel_drag_begin (GtkWidget      *widget, 
-                   GdkDragContext *drag_context, 
+_panel_drag_begin (GtkWidget      *widget,
+                   GdkDragContext *drag_context,
                    Panel          *panel)
 {
     gint         x, y, rootx, rooty;
     GtkWidget   *plugin;
-    
+
     DBG (" + drag begin");
-    
+
     /* get the pointer position */
     gdk_display_get_pointer (gtk_widget_get_display (widget), NULL, &x, &y, NULL);
-    
+
     /* get the window root coordinates */
     gdk_window_get_root_origin (widget->window, &rootx, &rooty);
-    
+
     /* calc the position inside the panel */
     x -= rootx;
     y -= rooty;
-    
+
     /* get the plugin on the itembar at this position */
     plugin = xfce_itembar_get_item_at_point (XFCE_ITEMBAR (widget), x, y);
-    
+
     /* start an item move */
     if (G_LIKELY (plugin))
         _item_start_move (plugin, panel);
@@ -558,18 +555,17 @@ _panel_drag_begin (GtkWidget      *widget,
  */
 static gboolean
 _panel_itembar_button_pressed (GtkWidget      *widget,
-                               GdkEventButton *ev, 
+                               GdkEventButton *ev,
                                Panel          *panel)
 {
     GtkWidget *plugin;
-    
+    guint      modifiers;
+
     if (xfce_itembar_event_window_is_raised (XFCE_ITEMBAR (widget)))
     {
-        guint modifiers;
-
         modifiers = gtk_accelerator_get_default_mod_mask ();
 
-        if (ev->button == 3 || (ev->button == 1 && 
+        if (ev->button == 3 || (ev->button == 1 &&
             (ev->state & modifiers) == GDK_CONTROL_MASK))
         {
             plugin = xfce_itembar_get_item_at_point (XFCE_ITEMBAR (widget),
@@ -581,7 +577,7 @@ _panel_itembar_button_pressed (GtkWidget      *widget,
             }
         }
     }
-    
+
     return FALSE;
 }
 
@@ -596,7 +592,7 @@ _panel_create_menu (Panel *panel)
 
     if (xfce_allow_panel_customization ())
     {
-        mi = gtk_image_menu_item_new_with_label (_("Customize Panel"));
+        mi = gtk_image_menu_item_new_with_label (_("Customize Panel..."));
         gtk_widget_show (mi);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
 
@@ -604,10 +600,10 @@ _panel_create_menu (Panel *panel)
         gtk_widget_show (img);
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
 
-        g_signal_connect (mi, "activate", G_CALLBACK (panel_app_customize), 
+        g_signal_connect (mi, "activate", G_CALLBACK (panel_app_customize),
                           NULL);
-        
-        mi = gtk_image_menu_item_new_with_label (_("Add Items"));
+
+        mi = gtk_image_menu_item_new_with_label (_("Add New Items..."));
         gtk_widget_show (mi);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
 
@@ -615,38 +611,38 @@ _panel_create_menu (Panel *panel)
         gtk_widget_show (img);
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
 
-        g_signal_connect_swapped (mi, "activate", 
+        g_signal_connect_swapped (mi, "activate",
                                   G_CALLBACK (panel_app_customize_items), NULL);
-        
+
+        mi = gtk_separator_menu_item_new ();
+        gtk_widget_show (mi);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+
+        mi = gtk_image_menu_item_new_with_label (_("Quit"));
+        gtk_widget_show (mi);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+
+        img = gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
+        gtk_widget_show (img);
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
+
+        g_signal_connect (mi, "activate", G_CALLBACK (panel_app_quit), NULL);
+
+        mi = gtk_image_menu_item_new_with_label (_("Restart"));
+        gtk_widget_show (mi);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+
+        img = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_MENU);
+        gtk_widget_show (img);
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
+
+        g_signal_connect (mi, "activate", G_CALLBACK (panel_app_restart), NULL);
+
         mi = gtk_separator_menu_item_new ();
         gtk_widget_show (mi);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
     }
 
-    mi = gtk_image_menu_item_new_with_label (_("Quit"));
-    gtk_widget_show (mi);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-
-    img = gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
-    gtk_widget_show (img);
-    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
-
-    g_signal_connect (mi, "activate", G_CALLBACK (panel_app_quit), NULL);
-    
-    mi = gtk_image_menu_item_new_with_label (_("Restart"));
-    gtk_widget_show (mi);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    
-    img = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_MENU);
-    gtk_widget_show (img);
-    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
-
-    g_signal_connect (mi, "activate", G_CALLBACK (panel_app_restart), NULL);
-
-    mi = gtk_separator_menu_item_new ();
-    gtk_widget_show (mi);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    
     mi = gtk_image_menu_item_new_with_label (_("About the Xfce Panel"));
     gtk_widget_show (mi);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
@@ -655,7 +651,7 @@ _panel_create_menu (Panel *panel)
     gtk_widget_show (img);
     gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
 
-    g_signal_connect_swapped (mi, "activate", G_CALLBACK (panel_app_about), 
+    g_signal_connect_swapped (mi, "activate", G_CALLBACK (panel_app_about),
                               panel);
 
     return menu;
@@ -666,7 +662,7 @@ _panel_create_menu (Panel *panel)
 Panel *
 panel_new (void)
 {
-    return PANEL (g_object_new (PANEL_TYPE_PANEL, NULL)); 
+    return PANEL (g_object_new (PANEL_TYPE_PANEL, NULL));
 }
 
 void
@@ -676,19 +672,19 @@ panel_free_data (Panel *panel)
     GList        *l;
     int           i;
 
-    g_return_if_fail (PANEL_IS_PANEL (panel));
-    
+    _panel_return_if_fail (PANEL_IS_PANEL (panel));
+
     priv = panel->priv;
 
     /* try and prevent some race conditions */
     priv->block_autohide++;
-    xfce_panel_window_set_move_function (XFCE_PANEL_WINDOW (panel), 
+    xfce_panel_window_set_move_function (XFCE_PANEL_WINDOW (panel),
                                          NULL, NULL);
-    xfce_panel_window_set_resize_function (XFCE_PANEL_WINDOW (panel), 
+    xfce_panel_window_set_resize_function (XFCE_PANEL_WINDOW (panel),
                                            NULL, NULL);
 
     for (l = gtk_container_get_children (GTK_CONTAINER (priv->itembar));
-         l != NULL; 
+         l != NULL;
          l = l->next)
     {
         XfcePanelItem *item = l->data;
@@ -699,31 +695,31 @@ panel_free_data (Panel *panel)
     g_list_free (l);
 
     /* give plugins the chance to quit */
-    for (i = 0;  i < 10 && 
+    for (i = 0;  i < 10 &&
          xfce_itembar_get_n_items (XFCE_ITEMBAR (priv->itembar)) != 0; ++i)
     {
-        DBG (" + %d item(s) on the panel", 
+        DBG (" + %d item(s) on the panel",
              xfce_itembar_get_n_items (XFCE_ITEMBAR (priv->itembar)));
         g_usleep (200000); /* 0.2 sec */
 
         while (gtk_events_pending ())
             gtk_main_iteration ();
     }
-            
+
 }
 
 /* items */
 
-static void 
+static void
 panel_menu_deactivated (GtkWidget *item)
 {
     int    x, y, w, h, px, py;
     Panel *panel = PANEL (item->parent->parent);
 
-    g_return_if_fail (PANEL_IS_PANEL (panel));
+    _panel_return_if_fail (PANEL_IS_PANEL (panel));
 
     panel_unblock_autohide (panel);
-    
+
     gdk_display_get_pointer (gdk_display_get_default (), NULL, &px, &py, NULL);
 
     gtk_window_get_position (GTK_WINDOW (panel), &x, &y);
@@ -745,25 +741,27 @@ panel_menu_deactivated (GtkWidget *item)
 static void
 panel_menu_opened (GtkWidget *item)
 {
-    g_return_if_fail (PANEL_IS_PANEL (item->parent->parent));
+    _panel_return_if_fail (PANEL_IS_PANEL (item->parent->parent));
 
     panel_block_autohide (PANEL (item->parent->parent));
 }
 
 static void
-_item_expand_changed (GtkWidget *item, 
-                      gboolean   expand, 
+_item_expand_changed (GtkWidget *item,
+                      gboolean   expand,
                       Panel     *panel)
 {
     PanelPrivate *priv;
 
-    g_return_if_fail (PANEL_IS_PANEL (panel));
-    
+    _panel_return_if_fail (PANEL_IS_PANEL (panel));
+
     priv = panel->priv;
 
     xfce_itembar_set_child_expand (XFCE_ITEMBAR (priv->itembar), item, expand);
 }
 
+
+
 static void
 _item_start_move_end (GtkWidget      *item,
                       GdkDragContext *context,
@@ -771,17 +769,17 @@ _item_start_move_end (GtkWidget      *item,
 {
     PanelPrivate *priv = panel->priv;
     Panel        *p;
-    
+
     DBG ("+ finish item drag");
-    
+
     /* disconnect drag end signal */
     g_signal_handlers_disconnect_by_func (G_OBJECT (item), G_CALLBACK (_item_start_move_end), panel);
-    
+
     if (!priv->edit_mode)
     {
         const GPtrArray *panels = panel_app_get_panel_list ();
-        gint i;
-        
+        guint i;
+
         for (i = 0; i < panels->len; ++i)
         {
             p = g_ptr_array_index (panels, i);
@@ -795,15 +793,17 @@ _item_start_move_end (GtkWidget      *item,
     }
 }
 
+
+
 static void
-_item_start_move (GtkWidget *item, 
+_item_start_move (GtkWidget *item,
                   Panel     *panel)
 {
     const GPtrArray *panels = panel_app_get_panel_list ();
     PanelPrivate    *priv;
     Panel           *p;
-    gint             i;
-    
+    guint             i;
+
     for (i = 0; i < panels->len; ++i)
     {
         p    = g_ptr_array_index (panels, i);
@@ -819,32 +819,31 @@ _item_start_move (GtkWidget *item,
 
     /* start the drag */
     panel_dnd_begin_drag (item);
-    
+
     /* signal to make panels sensitive after a drop */
     g_signal_connect (G_OBJECT (item), "drag-end", G_CALLBACK (_item_start_move_end), panel);
 }
 
-extern void panel_set_hidden (Panel    *panel, 
-                              gboolean  hide);
+
 
 static void
-_item_set_panel_hidden (GtkWidget *item, 
-                        gboolean   hidden, 
+_item_set_panel_hidden (GtkWidget *item,
+                        gboolean   hidden,
                         Panel     *panel)
 {
     PanelPrivate *priv;
 
-    g_return_if_fail (PANEL_IS_PANEL (panel));
-    
+    _panel_return_if_fail (PANEL_IS_PANEL (panel));
+
     priv = panel->priv;
-    
+
     if (priv->autohide)
         panel_set_hidden (panel, hidden);
 }
 
 static void
-panel_insert_widget (Panel     *panel, 
-                     GtkWidget *item, 
+panel_insert_widget (Panel     *panel,
+                     GtkWidget *item,
                      int        position)
 {
     PanelPrivate *priv = panel->priv;
@@ -867,8 +866,8 @@ panel_insert_widget (Panel     *panel,
 }
 
 static GtkWidget *
-panel_create_item (Panel      *panel, 
-                   const char *name, 
+panel_create_item (Panel      *panel,
+                   const char *name,
                    const char *id)
 {
     PanelPrivate *priv;
@@ -879,32 +878,32 @@ panel_create_item (Panel      *panel,
     xmon = panel_app_get_monitor (priv->monitor);
 
     item = xfce_panel_item_manager_create_item (xmon->screen,
-                                                name, 
-                                                id, 
-                                                priv->size, 
+                                                name,
+                                                id,
+                                                priv->size,
                                                 priv->screen_position);
 
     if (item != NULL)
     {
-        g_signal_connect (item, "menu-deactivated", 
+        g_signal_connect (item, "menu-deactivated",
                           G_CALLBACK (panel_menu_deactivated), panel);
-        
-        g_signal_connect (item, "menu-opened", 
+
+        g_signal_connect (item, "menu-opened",
                           G_CALLBACK (panel_menu_opened), panel);
-        
-        g_signal_connect (item, "expand-changed", 
+
+        g_signal_connect (item, "expand-changed",
                           G_CALLBACK (_item_expand_changed), panel);
-        
-        g_signal_connect (item, "customize-panel", 
+
+        g_signal_connect (item, "customize-panel",
                           G_CALLBACK (panel_app_customize), NULL);
-        
-        g_signal_connect (item, "customize-items", 
+
+        g_signal_connect (item, "customize-items",
                           G_CALLBACK (panel_app_customize_items), NULL);
-        
-        g_signal_connect (item, "move", 
+
+        g_signal_connect (item, "move",
                           G_CALLBACK (_item_start_move), panel);
-        
-        g_signal_connect (item, "set-hidden", 
+
+        g_signal_connect (item, "set-hidden",
                           G_CALLBACK (_item_set_panel_hidden), panel);
     }
 
@@ -916,15 +915,15 @@ _panel_get_new_id (void)
 {
     static int  counter = 0;
     static char id[30];
-    
+
     /* unique number: pseudo-random time() + counter */
     g_snprintf (id, sizeof(id), "%ld%d", (glong) time (NULL), counter++);
-    
+
     return id;
 }
 
 GtkWidget *
-panel_add_item_with_id (Panel      *panel, 
+panel_add_item_with_id (Panel      *panel,
                         const char *name,
                         const char *id)
 {
@@ -941,15 +940,15 @@ panel_add_item_with_id (Panel      *panel,
 }
 
 GtkWidget *
-panel_add_item (Panel      *panel, 
+panel_add_item (Panel      *panel,
                 const char *name)
 {
     return panel_add_item_with_id (panel, name, _panel_get_new_id ());
 }
 
-GtkWidget * 
-panel_insert_item (Panel      *panel, 
-                   const char *name, 
+GtkWidget *
+panel_insert_item (Panel      *panel,
+                   const char *name,
                    int         position)
 {
     GtkWidget *item;
@@ -981,25 +980,25 @@ panel_save_items (Panel *panel)
 {
     PanelPrivate *priv;
 
-    g_return_if_fail (PANEL_IS_PANEL (panel));
-    
+    _panel_return_if_fail (PANEL_IS_PANEL (panel));
+
     priv = panel->priv;
 
-    gtk_container_foreach (GTK_CONTAINER (priv->itembar), 
+    gtk_container_foreach (GTK_CONTAINER (priv->itembar),
                            (GtkCallback)xfce_panel_item_save, NULL);
 }
 
 /* convenience */
 
-gboolean 
+gboolean
 panel_is_horizontal (Panel *panel)
 {
     return (GTK_ORIENTATION_HORIZONTAL ==
             xfce_panel_window_get_orientation (XFCE_PANEL_WINDOW (panel)));
 }
 
-void 
-panel_set_items_sensitive (Panel    *panel, 
+void
+panel_set_items_sensitive (Panel    *panel,
                            gboolean  sensitive)
 {
     PanelPrivate *priv = panel->priv;
